summaryrefslogtreecommitdiff
authoralwin <alwin>2004-03-02 22:54:05 (UTC)
committer alwin <alwin>2004-03-02 22:54:05 (UTC)
commit3f5ca7734d2534ca90c13228504b6218f18f5afe (patch) (side-by-side diff)
tree088184edbeaf3891960428c4107f8b064001af5d
parent13348f11ba1cfa4787b973d65bfba8fc08299867 (diff)
downloadopie-3f5ca7734d2534ca90c13228504b6218f18f5afe.zip
opie-3f5ca7734d2534ca90c13228504b6218f18f5afe.tar.gz
opie-3f5ca7734d2534ca90c13228504b6218f18f5afe.tar.bz2
prefix correction for secondary namespace
Diffstat (more/less context) (ignore whitespace changes)
-rw-r--r--libopie2/templates/lib_cpp.cpp14
-rw-r--r--libopie2/templates/lib_h.h14
2 files changed, 14 insertions, 14 deletions
diff --git a/libopie2/templates/lib_cpp.cpp b/libopie2/templates/lib_cpp.cpp
index b3e25bd..e87d0f2 100644
--- a/libopie2/templates/lib_cpp.cpp
+++ b/libopie2/templates/lib_cpp.cpp
@@ -1,63 +1,63 @@
/*
* this file describes how the usage in namespaces in libopie2 should be done
* ODP is the namespace for whole opie2 stuff
* the parts are separated as follow:
* ONet: opienet2
* OPim: opiepim2
* ODb: opiedb2
* OCore: opiecore2
* OMm: opiemm2
* OUi: opieui2
* a class MUST start with O - so we make sure that it does not
* conflict with other stuff.
* don't use "using namespace .." in implementations.
*/
/*
This file is part of the Opie Project
Copyright (C) The Main Author <main-author@whereever.org>
=. Copyright (C) The Opie Team <opie-devel@handhelds.org>
.=l.
� � � � � �.>+-=
�_;:, � � .> � �:=|. This program is free software; you can
.> <`_, � > �. � <= redistribute it and/or modify it under
:`=1 )Y*s>-.-- � : the terms of the GNU Library General Public
.="- .-=="i, � � .._ License as published by the Free Software
�- . � .-<_> � � .<> Foundation; either version 2 of the License,
� � �._= =} � � � : or (at your option) any later version.
� � .%`+i> � � � _;_.
� � .i_,=:_. � � �-<s. This program is distributed in the hope that
� � �+ �. �-:. � � � = it will be useful, but WITHOUT ANY WARRANTY;
� � : .. � �.:, � � . . . without even the implied warranty of
� � =_ � � � �+ � � =;=|` MERCHANTABILITY or FITNESS FOR A
� _.=:. � � � : � �:=>`: PARTICULAR PURPOSE. See the GNU
..}^=.= � � � = � � � ; Library General Public License for more
++= � -. � � .` � � .: details.
�: � � = �...= . :.=-
�-. � .:....=;==+<; You should have received a copy of the GNU
� -_. . . � )=. �= Library General Public License along with
� � -- � � � �:-=` this library; see the file COPYING.LIB.
If not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
*/
#include <opie2/h.h>
/* OPIE */
opie (and for now, qpe) includes here
/* QT */
qte includes here
/* STD */
standard includes here
namespace ODP {
- namespace ONet {
+ namespace Net {
OFtpNetwork::OFtpNetwork() {
}
and so on.
@@ -1,63 +1,63 @@
* ODP is the namespace for whole opie2 stuff
* the parts are separated as follow:
- * ONet: opienet2
- * OPim: opiepim2
- * ODb: opiedb2
- * OCore: opiecore2
- * OMm: opiemm2
- * OUi: opieui2
+ * Net: opienet2
+ * Pim: opiepim2
+ * Db: opiedb2
+ * Core: opiecore2
+ * Mm: opiemm2
+ * Ui: opieui2
* a class MUST start with O - so we make sure that it does not
* conflict with other stuff.
}
}
diff --git a/libopie2/templates/lib_h.h b/libopie2/templates/lib_h.h
index aec635f..f6eeb08 100644
--- a/libopie2/templates/lib_h.h
+++ b/libopie2/templates/lib_h.h
@@ -1,63 +1,63 @@
/*
* this file describes how the usage in namespaces in libopie2 should be done
* ODP is the namespace for whole opie2 stuff
* the parts are separated as follow:
* ONet: opienet2
* OPim: opiepim2
* ODb: opiedb2
* OCore: opiecore2
* OMm: opiemm2
* OUi: opieui2
* a class MUST start with O - so we make sure that it does not
* conflict with other stuff.
* don't use "using namespace .." in implementations.
*/
/*
This file is part of the Opie Project
Copyright (C) The Main Author <main-author@whereever.org>
=. Copyright (C) The Opie Team <opie-devel@handhelds.org>
.=l.
� � � � � �.>+-=
�_;:, � � .> � �:=|. This program is free software; you can
.> <`_, � > �. � <= redistribute it and/or modify it under
:`=1 )Y*s>-.-- � : the terms of the GNU Library General Public
.="- .-=="i, � � .._ License as published by the Free Software
�- . � .-<_> � � .<> Foundation; either version 2 of the License,
� � �._= =} � � � : or (at your option) any later version.
� � .%`+i> � � � _;_.
� � .i_,=:_. � � �-<s. This program is distributed in the hope that
� � �+ �. �-:. � � � = it will be useful, but WITHOUT ANY WARRANTY;
� � : .. � �.:, � � . . . without even the implied warranty of
� � =_ � � � �+ � � =;=|` MERCHANTABILITY or FITNESS FOR A
� _.=:. � � � : � �:=>`: PARTICULAR PURPOSE. See the GNU
..}^=.= � � � = � � � ; Library General Public License for more
++= � -. � � .` � � .: details.
�: � � = �...= . :.=-
�-. � .:....=;==+<; You should have received a copy of the GNU
� -_. . . � )=. �= Library General Public License along with
� � -- � � � �:-=` this library; see the file COPYING.LIB.
If not, write to the Free Software Foundation,
Inc., 59 Temple Place - Suite 330,
Boston, MA 02111-1307, USA.
*/
#ifndef THISFILE_H
#define THISFILE_H
/* OPIE */
opie (and for now, qpe) includes here
/* QT */
qte includes here
/* STD */
namespace ODP
{
- namspace ONet {
+ namspace Net {
classes here
}
}
@@ -1,63 +1,63 @@
* ODP is the namespace for whole opie2 stuff
* the parts are separated as follow:
- * ONet: opienet2
- * OPim: opiepim2
- * ODb: opiedb2
- * OCore: opiecore2
- * OMm: opiemm2
- * OUi: opieui2
+ * Net: opienet2
+ * Pim: opiepim2
+ * Db: opiedb2
+ * Core: opiecore2
+ * Mm: opiemm2
+ * Ui: opieui2
* a class MUST start with O - so we make sure that it does not
* conflict with other stuff.
#endif